You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by as...@apache.org on 2021/03/23 17:31:43 UTC

[camel-k] 02/03: fix: Do not use operator version to compute IntegrationKit digest

This is an automated email from the ASF dual-hosted git repository.

astefanutti pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/camel-k.git

commit 583f3ee89473e8cc23f6763ac06596595af58c89
Author: Antonin Stefanutti <an...@stefanutti.fr>
AuthorDate: Tue Mar 23 14:40:48 2021 +0100

    fix: Do not use operator version to compute IntegrationKit digest
---
 pkg/util/digest/digest.go | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/pkg/util/digest/digest.go b/pkg/util/digest/digest.go
index 2decff7..c63259c 100644
--- a/pkg/util/digest/digest.go
+++ b/pkg/util/digest/digest.go
@@ -130,8 +130,8 @@ func ComputeForIntegration(integration *v1.Integration) (string, error) {
 // Produces a digest that can be used as docker image tag
 func ComputeForIntegrationKit(kit *v1.IntegrationKit) (string, error) {
 	hash := sha256.New()
-	// Operator version is relevant
-	if _, err := hash.Write([]byte(defaults.Version)); err != nil {
+	// Kit version is relevant
+	if _, err := hash.Write([]byte(kit.Status.Version)); err != nil {
 		return "", err
 	}